pub struct DisableAllSimdError {
pub errors: Vec<CompileTimeGuaranteedError>,
}Expand description
Error returned when dangerously_disable_tokens_except_wasm fails to
disable one or more tokens because their features are compile-time enabled.
Contains the individual CompileTimeGuaranteedError for each token that
could not be disabled.
Fields
errors: Vec<CompileTimeGuaranteedError>The individual errors for each token that could not be disabled.